@@ -403,7 +403,6 @@ class IO(object):
 
         for files in os.listdir(experimentdirectory):
             if files.endswith('.frd'):
-                ignoreregenerationaandneutralization = False
                 Xdata = []
                 Ydata = []
                 StepName = []
@@ -433,11 +432,6 @@ class IO(object):
                         for commondata in stepdata.findall('CommonData'):
 
                             WellType.append(commondata.find('WellType').text)
-                            if ignoreregenerationaandneutralization:
-                                if WellType[-1].upper() == 'REGENERATION' or WellType[-1] == 'NEUTRALIZATION':
-                                    WellType.pop()
-                                    continue
-
                             Concentration.append(commondata.find('Concentration').text)
                             MolarConcentration.append(commondata.find('MolarConcentration').text)
                             SampleID.append(commondata.find('SampleID').text)
@@ -445,7 +439,6 @@ class IO(object):
                                 SampleGroup.append(commondata.find('SampleGroup').text)
                             else:
                                 SampleGroup.append(None)
-                            WellType.append(commondata.find('WellType').text)
                             MW.append(commondata.find('MolecularWeight').text)
                             Xdata.append(np.array(array.array('f', base64.b64decode(stepdata.find('AssayXData').text))))
                             Ydata.append(np.array(array.array('f', base64.b64decode(stepdata.find('AssayYData').text))))
@@ -470,18 +463,29 @@ class IO(object):
                     newbuffer.data.x.append(segment)
                     newbuffer.plot.axis.x.lines.append(segment[0])
 
-                for segment in Ydata:
-                    newbuffer.data.y.append(segment)
+                for j, segment in enumerate(Ydata):
+                    signal_shift = 0.0
+                    if j > 0:
+                        signal_shift = segment[0]-Ydata[j-1][-1]
+                    newbuffer.data.y.append(segment - signal_shift)
 
                 newbuffer.data.z.set([float(MolarConcentration[-2])] * newbuffer.data.y.length())
 
-                newbuffer.comments.set([SensorInfo + " on " + SensorType + " vs " +
-                                           SampleID[-2] + " @ " + MolarConcentration[-2] + "nM"])
+                newbuffer.comments.set([str(SensorInfo) + " on " + str(SensorType) + " vs " +
+                                           str(SampleID[-2]) + " @ " + str(MolarConcentration[-2]) + "nM"])
                 newbuffer.plot.series.name.set(newbuffer.comments.get())
                 newbuffer.plot.title.set(newbuffer.comments.get())
                 newbuffer.plot.axis.x.title.set("Time (s)")
                 newbuffer.plot.axis.y.title.set("Response (nm)")
                 newbuffer.plot.axis.x.lines.show()
+                newbuffer.meta_dict = {'xData': Xdata, 'yData': Ydata,
+                                       'stepName': StepName, 'actualTime': ActualTime, 'sensorType': SensorType,
+                                       'stepStatus': StepStatus, 'stepType': StepType, 'concentration': Concentration,
+                                       'molarConcentration':MolarConcentration, 'sampleID':SampleID,
+                                       'wellType': WellType, 'mw': MW, 'flags':Flags, 'sampleGroup': SampleGroup,
+                                       'stepLocation': StepLoc, 'loadingSample': loadingsample, 'sensorInfo': SensorInfo,
+                                       'loadingStart':loadingstart, 'loadingEnd':loadingend, 'loadingWell':loadingwell,
+                                       'inFile':infile, 'sensorName':SensorName}
                 self.data.matrix.add_buffer(newbuffer)
         self.colorallseries()
         return "ForteBio data read into memory."
@@ -730,6 +734,3 @@ def predict_encoding(file_path, n_lines=20):
         rawdata = b''.join([f.readline() for _ in range(n_lines)])
     return chardet.detect(rawdata)['encoding']
 
-
-
-
