@@ -26,18 +26,28 @@ class plotter(object):
         self.__resid_ax = False
         self.__scatter_ax = False
         self.__scatter_fig = False
+        self.__plot = None
+        self.__startplot = None
         self.inst = data_instance
 
     def __call__(self, pltarray, *args, **kwargs):
         print("Plotting...")
+        pl.close('all')
         return_bytes = False
         scan = False
         auto = False
         delay = 0.5
-        start_plot = None
         dpi = 50
         tight = True
-        plot = None
+        self.__global_xlim = (-0.1, 0.1)
+        self.__global_ylim = (-0.1, 0.1)
+        self.__global_ylim_resid = (-0.1, 0.1)
+        self.__resid_ax = False
+        self.__scatter_ax = False
+        self.__scatter_fig = False
+        self.__plot = None
+        self.__startplot = None
+
 
         if 'get_bytes' in kwargs:
             return_bytes = bool(kwargs['get_bytes'])
@@ -65,13 +75,13 @@ class plotter(object):
             # determine plot type, and call correct routine
             plot_type = self.__get_plot_type(buffer)
             if plot_type == 'heatmap':
-                plot = self.__heatmap(buffer, *args, **kwargs)
+                self.__plot = self.__heatmap(buffer, *args, **kwargs)
             else:
                 # scatter/line plots can be superimposed so plot has to be initialized outside of plotting method to permit stacking
                 if i == 0:
-                    start_plot = pl.subplots(nrows=1, ncols=1, figsize=(8, 6), sharey=True, sharex=True)
+                    self.__start_plot = pl.subplots(nrows=1, ncols=1, figsize=(8, 6), sharey=True, sharex=True)
                     # pl.close('all')
-                start_plot, plot = self.__scatterline(buffer_number, start_plot, plot_type, *args, **kwargs)
+                self.__start_plot, self.__plot = self.__scatterline(buffer_number, plot_type, *args, **kwargs)
                 if not auto:
                     print(f"Displaying Buffer {buffer_number}")
 
@@ -90,7 +100,7 @@ class plotter(object):
 
         # if return bytes requested, return bytes
         if return_bytes:
-            return self.__get_byte_png(plot, dpi=dpi, tight=tight)
+            return self.__get_byte_png(self.__plot, dpi=dpi, tight=tight)
         return "Plotting Complete"
 
     def __get_plot_type(self, buffer):
@@ -128,8 +138,11 @@ class plotter(object):
         X_cat = buffer.category.x.get()
         Y_cat = buffer.category.y.get()
         X_title = buffer.plot.axis.x.title.get()
+        X_title_size = buffer.plot.axis.x.label.size.get()
         Y_title = buffer.plot.axis.y.title.get()
+        Y_title_size = buffer.plot.axis.y.label.size.get()
         Z_title = buffer.plot.axis.z.title.get()
+        Z_title_size = buffer.plot.axis.z.label.size.get()
         plot_title = buffer.plot.title.get()
 
         X_axis = X if not X_cat else X_cat
@@ -138,9 +151,9 @@ class plotter(object):
         data = Z.reshape((len(Y_axis), len(X_axis)))
 
         fig, ax = pl.subplots()
-        pl.rcParams["font.size"] = 10
-        pl.gca().tick_params(axis='y', pad=8)
-        pl.gca().tick_params(axis='x', pad=8)
+        pl.rcParams["font.size"] = min(X_title_size, Y_title_size)
+        pl.gca().tick_params(axis='y', pad=8, labelsize=Y_title_size)
+        pl.gca().tick_params(axis='x', pad=8, labelsize=X_title_size)
 
         # Plot the heatmap
         im = ax.imshow(data, cmap=matplotlib.cm.rainbow)
@@ -151,8 +164,8 @@ class plotter(object):
         # ... and label them with the respective list entries.
         ax.set_xticklabels(X_axis)
         ax.set_yticklabels(Y_axis)
-        pl.xlabel(X_title)
-        pl.ylabel(Y_title)
+        pl.xlabel(X_title, size=X_title_size)
+        pl.ylabel(Y_title, size=Y_title_size)
 
         # Let the horizontal axes labeling appear on top.
         ax.tick_params(top=True, bottom=False,
@@ -188,7 +201,7 @@ class plotter(object):
         fig.canvas.flush_events()
         return pl
 
-    def __scatterline(self, buffer_number, start_plot, plot_type, *args, **kwargs):
+    def __scatterline(self, buffer_number, plot_type, *args, **kwargs):
         buffer = self.inst.matrix._Matrix__buffer_list[buffer_number-1]
         black_models = False
         scan = False
@@ -207,28 +220,37 @@ class plotter(object):
         YE = buffer.data.ye.get()
         Z = buffer.data.z.get()
         ZE = buffer.data.ze.get()
+        show_data = buffer.data.is_visible
         X_model = buffer.model.x.get()
         Y_model = buffer.model.y.get()
         Z_model = buffer.model.z.get()
+        model_color = buffer.model.color.get()
+        show_model = buffer.model.is_visible
         X_resid = buffer.residuals.x.get()
         Y_resid = buffer.residuals.y.get()
         Z_resid = buffer.residuals.z.get()
+        show_residuals = buffer.residuals.is_visible
         series_color = matplotlib.colors.to_hex(buffer.plot.series.color.get() if buffer.plot.series.color.get() != '' else 'r', keep_alpha=True)
-        series_weight = buffer.plot.series.weight.get()
+        data_weight = buffer.plot.series.weight.get() if buffer.data.weight.get() <= 0 else buffer.data.weight.get()
+        model_weight = data_weight/5 if buffer.model.weight.get() <= 0 else buffer.model.weight.get() 
         x_axis_title = buffer.plot.axis.x.title.get()
         y_axis_title = buffer.plot.axis.y.title.get()
         z_axis_title = buffer.plot.axis.z.title.get()
+        x_title_size = buffer.plot.axis.x.label.size.get()
+        y_title_size = buffer.plot.axis.y.label.size.get()
+        z_title_size = buffer.plot.axis.z.label.size.get()
+        x_title_show = buffer.plot.axis.x.label.is_visible
+        y_title_show = buffer.plot.axis.y.label.is_visible
+        z_title_show = buffer.plot.axis.z.label.is_visible
         show_x_lines = buffer.plot.axis.x.lines.is_visible
         x_lines = buffer.plot.axis.x.lines.get()
         show_y_lines = buffer.plot.axis.y.lines.is_visible
-        y_lines = buffer.plot.axis.x.lines.get()
+        y_lines = buffer.plot.axis.y.lines.get()
         show_peaks = buffer.plot.axis.y.peaks.is_visible
         peak_indicies = buffer.plot.axis.y.peaks.get()
         peaks = [Y[p] for p in peak_indicies]
         show_peak_bounds = buffer.plot.axis.y.peak_bounds.is_visible
-        peak_bounds = buffer.plot.axis.y.peak_bounds.get()
-        peak_bounds_indicies = [tuple([buffer.data.y.nearest_index_to_value(p[0]),
-                                buffer.data.y.nearest_index_to_value(p[-1])]) for p in peak_bounds]
+        peak_bounds_indicies = buffer.plot.axis.y.peak_bounds.get()
         show_integrals = buffer.plot.axis.x.integrals.is_visible
         integral_indicies_pairs = buffer.plot.axis.x.integrals.get()
         show_polygons = buffer.plot.polygons.is_visible
@@ -244,18 +266,20 @@ class plotter(object):
         #####################################
         if scan: # if scan create new figure each iteration
             pass
-            # start_plot = pl.subplots(nrows=1, ncols=1, figsize=(8, 6), sharey=True, sharex=True)
+            # self.__start_plot = pl.subplots(nrows=1, ncols=1, figsize=(8, 6), sharey=True, sharex=True)
         if not self.__scatter_ax:
-            self.__scatter_fig, self.__scatter_ax = start_plot
+            self.__scatter_fig, self.__scatter_ax = self.__start_plot
             self.__scatter_ax.plot(1, 1)
             self.__scatter_ax.set_xscale(x_axis_type)
             self.__scatter_ax.set_yscale(y_axis_type)
             self.__scatter_ax.grid()
             pl.rcParams["font.size"] = 10
-            pl.gca().tick_params(axis='y', pad=8)
-            pl.gca().tick_params(axis='x', pad=8)
-            pl.xlabel(x_axis_title)
-            pl.ylabel(y_axis_title)
+            pl.gca().tick_params(axis='y', pad=8, labelsize=y_title_size)
+            pl.gca().tick_params(axis='x', pad=8, labelsize=x_title_size)
+            if x_title_show:
+                pl.xlabel(x_axis_title, size=x_title_size)
+            if y_title_show:
+                pl.ylabel(y_axis_title, size=y_title_size)
 
         if not scan and len(x_axis_range) > 0:
             # do nothing
@@ -289,61 +313,70 @@ class plotter(object):
         # If Z data, treat as heatmap scatter
         if len(Z) == 0 or len(set(Z)) == 1:
             if plot_type == 'scatter':
-                self.__scatter_ax.scatter(X, Y, color=series_color, s=series_weight * 4, zorder=0)  # weight is by area, correct to height val
+                self.__scatter_ax.scatter(X, Y, color=series_color, s=data_weight * 4, zorder=0)  # weight is by area, correct to height val
             else:
-                self.__scatter_ax.plot(X, Y, color=series_color, linestyle='-', linewidth=series_weight, zorder=0)
+                self.__scatter_ax.plot(X, Y, color=series_color, linestyle='-', linewidth=data_weight, zorder=0)
         else:
             # color points by z value and sort to not obscure data in plot
             sorted_X, sorted_Y, sorted_Z = self.__sort_by_z(X, Y, Z)
             if plot_type == 'scatter':
-                self.__scatter_ax.scatter(sorted_X, sorted_Y, c=sorted_Z, s=series_weight * 4, cmap=matplotlib.cm.rainbow, zorder=0)  # weight is by area, correct to height val
+                self.__scatter_ax.scatter(sorted_X, sorted_Y, c=sorted_Z, s=data_weight * 4, cmap=matplotlib.cm.rainbow, zorder=0)  # weight is by area, correct to height val
             else:
-                self.__scatter_ax.plot(sorted_X, sorted_Y, c=sorted_Z, linestyle='-', linewidth=series_weight, cmap=matplotlib.cm.rainbow, zorder=0)
+                self.__scatter_ax.plot(sorted_X, sorted_Y, c=sorted_Z, linestyle='-', linewidth=data_weight, cmap=matplotlib.cm.rainbow, zorder=0)
+
+        #####################################
+        #            Model Plot             #
+        # __________________________________#
+        if len(X_model) > 0 and show_model:
+            if black_models:
+                self.__scatter_ax.plot(X_model, Y_model, linestyle='-', color='#000000', linewidth=model_weight, zorder=1)
+            elif model_color == series_color:
+                self.__scatter_ax.plot(X_model, Y_model, linestyle='-', color=series_color, linewidth=model_weight,
+                        path_effects=[pe.Stroke(linewidth=model_weight *2, foreground='#000000'), pe.Normal()],
+                        zorder=1)
+            else:
+                self.__scatter_ax.plot(X_model, Y_model, linestyle='-', color=model_color, linewidth=model_weight,
+                                       zorder=1)
+        #___________________________________#
+        #        END Model Plot             #
+        #####################################
 
         #####################################
         #            Residual Plot          #
         # __________________________________#
-        if len(X_model) > 0:
-            if black_models:
-                self.__scatter_ax.plot(X_model, Y_model, linestyle='-', color='k', linewidth=series_weight / 5, zorder=1)
-            else:
-                self.__scatter_ax.plot(X_model, Y_model, linestyle='-', color=series_color, linewidth=series_weight / 5,
-                        path_effects=[pe.Stroke(linewidth=series_weight / 2.5, foreground='k'), pe.Normal()],
-                        zorder=1)
-            # residuals plot
-            if len(X_resid) > 0:
-                if not self.__resid_ax:
-                    divider = make_axes_locatable(self.__scatter_ax)
-                    self.__resid_ax = divider.append_axes("bottom", size="20%", pad=0)
-                    self.__scatter_ax.figure.add_axes(self.__resid_ax)
-                    self.__resid_ax.set_xscale(x_axis_type)
-                    self.__resid_ax.set_yscale(y_axis_type)
-                    # end residuals plot
-                    self.__scatter_ax.set_xticklabels([])
-                    pl.gca().yaxis.set_major_locator(MaxNLocator(prune='upper'))
-                    # Set x bounds to match data plot
-                    pl.xlim(min(x_axis_range), max(x_axis_range))
-                    pl.xlabel(x_axis_title)
-                    self.__resid_ax.axhline(y=0, linestyle='-', color='k', linewidth=2, zorder=0)
-                    self.__resid_ax.grid()
-                    pl.ylabel('Residuals')
-                self.__resid_ax.set_ylim(min(y_resid_axis_range), max(y_resid_axis_range))
-                self.__resid_ax.plot(X_resid, Y_resid, linestyle='-', color=series_color, linewidth=series_weight / 5)
-        # ___________________________________#
+        if len(X_resid) > 0 and None not in (min(y_resid_axis_range), max(y_resid_axis_range)) and show_residuals:
+            if not self.__resid_ax:
+                divider = make_axes_locatable(self.__scatter_ax)
+                self.__resid_ax = divider.append_axes("bottom", size="20%", pad=0)
+                self.__scatter_ax.figure.add_axes(self.__resid_ax)
+                self.__resid_ax.set_xscale(x_axis_type)
+                self.__resid_ax.set_yscale(y_axis_type)
+                # end residuals plot
+                self.__scatter_ax.set_xticklabels([])
+                pl.gca().yaxis.set_major_locator(MaxNLocator(prune='upper'))
+                # Set x bounds to match data plot
+                pl.xlim(min(x_axis_range), max(x_axis_range))
+                pl.xlabel(x_axis_title, size=x_title_size)
+                self.__resid_ax.axhline(y=0, linestyle='-', color='#000000', linewidth=2, zorder=0)
+                self.__resid_ax.grid()
+                pl.ylabel('Residuals')
+            self.__resid_ax.set_ylim(min(y_resid_axis_range), max(y_resid_axis_range))
+            self.__resid_ax.plot(X_resid, Y_resid, linestyle='-', color=series_color, linewidth=model_weight)
+        #___________________________________#
         #        END Residual Plot          #
         #####################################
 
         #####################################
         #     X-line and Y-line Plotting    #
-        # ___________________________________#
+        #___________________________________#
         if show_x_lines and len(x_lines) >= 1:
             for line in x_lines:
-                self.__scatter_ax.axvline(x=line, linestyle='--', color='gray', linewidth=series_weight / 5, zorder=2,
-                           path_effects=[pe.Stroke(linewidth=series_weight / 2.5, foreground='k'), pe.Normal()])
+                self.__scatter_ax.axvline(x=line, linestyle='--', color='#808080', linewidth=data_weight, zorder=2,
+                           path_effects=[pe.Stroke(linewidth=data_weight * 2, foreground='#000000'), pe.Normal()])
         if show_y_lines and len(y_lines) >= 1:
             for line in y_lines:
-                self.__scatter_ax.axhline(y=line, linestyle='--', color='gray', linewidth=series_weight / 5, zorder=2,
-                           path_effects=[pe.Stroke(linewidth=series_weight / 2.5, foreground='k'), pe.Normal()])
+                self.__scatter_ax.axhline(y=line, linestyle='--', color='#808080', linewidth=data_weight, zorder=2,
+                           path_effects=[pe.Stroke(linewidth=data_weight * 2, foreground='#000000'), pe.Normal()])
         # ___________________________________#
         #  END X-line and Y-line Plotting   #
         #####################################
@@ -357,7 +390,7 @@ class plotter(object):
             for p in peak_indicies:
                 peak_x.append(X[p])
                 peak_y.append(Y[p])
-            self.__scatter_ax.plot(peak_x, peak_y, "d", markerfacecolor='gainsboro', markeredgecolor='k', zorder=3)
+            self.__scatter_ax.plot(peak_x, peak_y, "d", markerfacecolor='#808080', markeredgecolor='#000000', zorder=3)
         if show_peak_bounds and len(peak_bounds_indicies) >= 1:
             peak_bound_x = []
             peak_bound_y = []
@@ -368,7 +401,7 @@ class plotter(object):
                 peak_bound_y.append(Y[p_start])
                 peak_bound_x.append(X[p_end])
                 peak_bound_y.append(Y[p_end])
-            self.__scatter_ax.plot(peak_bound_x, peak_bound_y, "d", markerfacecolor='gainsboro', markeredgecolor='k', zorder=3)
+            self.__scatter_ax.plot(peak_bound_x, peak_bound_y, "d", markerfacecolor='#808080', markeredgecolor='#000000', zorder=3)
         # ___________________________________#
         #       END Peak Plotting           #
         #####################################
@@ -389,7 +422,7 @@ class plotter(object):
                 int_start = (X[int_indx[0]], Y[int_indx[0]])
                 int_end = (X[int_indx[-1]], Y[int_indx[-1]])
                 verts = [(int_start[0], 0)] + xy_vals[int_indx[0]:int_indx[1]] + [(int_end[0], 0)]
-                poly = matplotlib.patches.Polygon(verts, facecolor=int_color, edgecolor='gainsboro', zorder=0)
+                poly = matplotlib.patches.Polygon(verts, facecolor=int_color, edgecolor='#808080', zorder=0)
                 self.__scatter_ax.add_patch(poly)
         # ___________________________________#
         #     END  Integral  Plotting       #
@@ -401,8 +434,8 @@ class plotter(object):
         if show_polygons and len(polygon_verticies) >= 1:
             for polygon in polygon_verticies:
                 poly_x, poly_y = zip(*polygon)
-                self.__scatter_ax.plot(poly_x, poly_y, linestyle='-', color='gainsboro', linewidth=series_weight / 5, zorder=4,
-                        path_effects=[pe.Stroke(linewidth=series_weight / 2.5, foreground='k'), pe.Normal()])
+                self.__scatter_ax.plot(poly_x, poly_y, linestyle='-', color='#808080', linewidth=data_weight, zorder=4,
+                        path_effects=[pe.Stroke(linewidth=data_weight * 2, foreground='k'), pe.Normal()])
         # ___________________________________#
         #       END  Polygon Plotting       #
         #####################################
@@ -411,10 +444,12 @@ class plotter(object):
         return [self.__scatter_fig, self.__scatter_ax], pl
 
     def __get_byte_png(self, pl, dpi=50, tight=True):
+        global is_savefig
         BIOstream = BIO()
-        if tight:
-            pl.tight_layout()
+        is_savefig = True
         pl.savefig(BIOstream, format='png', dpi=dpi, bbox_inches='tight')
+        pl.close('all')
+        is_savefig = False
         BIOstream.seek(0)
         im = Image.open(BIOstream)
         im2 = im.convert('RGB').convert('P', palette=Image.ADAPTIVE)
@@ -423,7 +458,7 @@ class plotter(object):
         im2.save(BIOstream, format='PNG', quality=95)
         BIOstream.seek(0)
         byte_png = BIOstream.getvalue()
-        pl.close()
+        pl.close('all')
         return byte_png
 
     def __sort_by_z(self, X, Y, Z):
